==> uoa-search-3.5.10-20200727.103850-3-sources.jar: eu/dnetlib/data/search/web/api/CSVResponseFormat.java <==
package eu.dnetlib.data.search.web.api;

import eu.dnetlib.data.search.web.utils.RequestResponseHandler;
import org.apache.log4j.Logger;

/**
 * Created by kiatrop on 20/12/2016.
 */
public class CSVResponseFormat {

    public static final String organization = "Name,Projects,Country\n";
    public static final String datasource = "Name,Type,Compatibility,OAI-PMH,website\n";
    public static final String person = "Fullname\n";
    public static final String project = "Title,Funder,Start Date,End Date,Participants\n";
    public static final String result = "Type,Title,Authors,Publication Year,DOI,Funder|Project Name (GA Number),Access\n";

    //TODO SPECIAL
    public static final String result_special = "Type,Title,Authors,Publication Year,DOI,Download from,Type,Journal,Funder,Project Name (GA Number),Access\n";

    private static Logger logger = Logger.getLogger(CSVResponseFormat.class);


    public static final String response = "%s%s";

    public static String appendTitle(RequestResponseHandler.Entity entity, boolean special) {
        if(entity.equals(RequestResponseHandler.Entity.ORGANIZATION)) {
            return  organization;

        } else if (entity.equals(RequestResponseHandler.Entity.DATASOURCE)) {
            return  datasource;

        }/* else if (entity.equals(RequestResponseHandler.Entity.PERSON)) {
            return  person;

        }*/ else if (entity.equals(RequestResponseHandler.Entity.PROJECT)) {
            return project;

        } else if (entity.equals(RequestResponseHandler.Entity.PUBLICATION) || entity.equals(RequestResponseHandler.Entity.DATASET)
                    ||entity.equals(RequestResponseHandler.Entity.SOFTWARE) || entity.equals(RequestResponseHandler.Entity.OTHER)
                    || entity.equals(RequestResponseHandler.Entity.RESULT)) {

            if (special) {
                return result_special;
            }

            return result;
        }

        return "";
    }



}

==> uoa-search-3.5.10-20200727.130845-6-sources.jar: eu/dnetlib/data/search/web/api/CSVResponseFormat.java <==
package eu.dnetlib.data.search.web.api;

import eu.dnetlib.data.search.web.utils.RequestResponseHandler;
import org.apache.log4j.Logger;

/**
 * Created by kiatrop on 20/12/2016.
 */
public class CSVResponseFormat {

    public static final String organization = "Name,Projects,Country\n";
    public static final String datasource = "Name,Type,Compatibility,OAI-PMH,website\n";
    public static final String person = "Fullname\n";
    public static final String project = "Title,Funder,Start Date,End Date,Participants\n";
    public static final String result = "Type,Title,Authors,Publication Year,DOI,Download from,Type,Journal,Funder|Project Name (GA Number),Access\n";

    //TODO SPECIAL
    public static final String result_special = "Type,Title,Authors,Publication Year,DOI,Download from,Type,Journal,Funder,Project Name (GA Number),Access\n";

    private static Logger logger = Logger.getLogger(CSVResponseFormat.class);


    public static final String response = "%s%s";

    public static String appendTitle(RequestResponseHandler.Entity entity, boolean special) {
        if(entity.equals(RequestResponseHandler.Entity.ORGANIZATION)) {
            return  organization;

        } else if (entity.equals(RequestResponseHandler.Entity.DATASOURCE)) {
            return  datasource;

        }/* else if (entity.equals(RequestResponseHandler.Entity.PERSON)) {
            return  person;

        }*/ else if (entity.equals(RequestResponseHandler.Entity.PROJECT)) {
            return project;

        } else if (entity.equals(RequestResponseHandler.Entity.PUBLICATION) || entity.equals(RequestResponseHandler.Entity.DATASET)
                    ||entity.equals(RequestResponseHandler.Entity.SOFTWARE) || entity.equals(RequestResponseHandler.Entity.OTHER)
                    || entity.equals(RequestResponseHandler.Entity.RESULT)) {

            if (special) {
                return result_special;
            }

            return result;
        }

        return "";
    }



}
